# Slot: required


true means that the slot must be present in the loaded definition

URI: [http://w3id.org/biolink/biolinkml/meta/required](slot_uri)
## Domain and Range

[SlotDefinition](SlotDefinition.md) -><sub>opt</sub> [Boolean](Boolean.md)
## Inheritance

## Children

## Used by

 * [SlotDefinition](SlotDefinition.md)
